==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/gl.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "activated" : "activado",
    "updated" : "actualizado",
    "mounted" : "montado",
    "deactivated" : "desactivado",
    "beforeCreate" : "antesDaCreación",
    "created" : "creado",
    "beforeUpdate" : "antesDaActualización",
    "beforeDestroy" : "antesDaDestrución",
    "destroyed" : "destruído",
    "beforeMount" : "antesDaMontaxe",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Estes son os seus códigos de seguranza. Gárdeos e/ou imprímaos xa que non poderá volver lelos de novo.",
    "Save backup codes" : "Gardar os códigos de seguranza",
    "Print backup codes" : "Imprimir os códigos de seguranza",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Os códigos de seguranza foron xerados. Usou {used} códigos de {total}.",
    "Regenerate backup codes" : "Rexenerar códigos de seguranza",
    "_icon-loading-small_::_generate-backup-codes_" : ["icona-de-carga-pequena","xerar-códigos-de-seguranza "],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Se rexenera os códigos de seguranza, automaticamente invalidara os antigos códigos.",
    "Generate backup codes" : "Xerar códigos de seguranza",
    "An error occurred while generating your backup codes" : "Produciuse un erro ao rexenerar os seus códigos de seguranza",
    "Nextcloud backup codes" : "Códigos de seguranza do Nextcloud",
    "You created two-factor backup codes for your account" : "Creou códigos de seguranza de dous factores para a súa conta",
    "Second-factor backup codes" : "Códigos de seguranza do segundo factor",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Activou a autenticación de dous factores mais non xerou aída os códigos de seguranza. Asegúrese de facelo para o caso de perda de acceso ao seu segundo factor.",
    "Backup code" : "Código de seguranza",
    "Use backup code" : "Usar código de seguranza",
    "Two factor backup codes" : "Códigos de seguranza de dous factores",
    "A two-factor auth backup codes provider" : "Un fornecedor de códigos de seguranza para a autenticación de dous factores",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Use un dos códigos de seguranza que gardou cuando axustou a autenticación de dous factores.",
    "Submit" : "Enviar ",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Los códigos de seguranza foron xerados. Usou {{used}} códigos de {{total}}."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/gl.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Estes son os seus códigos de seguranza. Gárdeos e/ou imprímaos xa que non poderá volver lelos de novo.",
    "Save backup codes" : "Gardar os códigos de seguranza",
    "Print backup codes" : "Imprimir os códigos de seguranza",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Os códigos de seguranza foron xerados. Usou {used} códigos de {total}.",
    "Regenerate backup codes" : "Rexenerar códigos de seguranza",
    "_icon-loading-small_::_generate-backup-codes_" : ["icona-de-carga-pequena","xerar-códigos-de-seguranza "],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Se rexenera os códigos de seguranza, automaticamente invalidara os antigos códigos.",
    "Generate backup codes" : "Xerar códigos de seguranza",
    "An error occurred while generating your backup codes" : "Produciuse un erro ao rexenerar os seus códigos de seguranza",
    "Nextcloud backup codes" : "Códigos de seguranza do Nextcloud",
    "You created two-factor backup codes for your account" : "Creou códigos de seguranza de dous factores para a súa conta",
    "Second-factor backup codes" : "Códigos de seguranza do segundo factor",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Activou a autenticación de dous factores mais non xerou aída os códigos de seguranza. Asegúrese de facelo para o caso de perda de acceso ao seu segundo factor.",
    "Backup code" : "Código de seguranza",
    "Use backup code" : "Usar código de seguranza",
    "Two factor backup codes" : "Códigos de seguranza de dous factores",
    "A two-factor auth backup codes provider" : "Un provedor de códigos de seguranza para a autenticación de dous factores",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Use un dos códigos de seguranza que gardou cuando axustou a autenticación de dous factores.",
    "Submit" : "Enviar ",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Los códigos de seguranza foron xerados. Usou {{used}} códigos de {{total}}.",
    "activated" : "activado",
    "updated" : "actualizado",
    "mounted" : "montado",
    "deactivated" : "desactivado",
    "beforeCreate" : "antesDaCreación",
    "created" : "creado",
    "beforeUpdate" : "antesDaActualización",
    "beforeDestroy" : "antesDaDestrución",
    "destroyed" : "destruído",
    "beforeMount" : "antesDaMontaxe"
},
"nplurals=2; plural=(n != 1);");
